@@ -1,4 +1,4 @@
-/* Copyright (c) 2012-2014, The Trusted Domain Project.  All rights reserved. */
+/* Copyright (c) 2012-2015, The Trusted Domain Project.  All rights reserved. */
 
 #ifndef DMARC_H
 #define DMARC_H
@@ -7,11 +7,13 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#include <sys/param.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#include <resolv.h>
 
-#define	OPENDMARC_LIB_VERSION	0x01030000
+#define	OPENDMARC_LIB_VERSION	0x01030100
 
 #define	DMARC_MAXHOSTNAMELEN		(256)
 
@@ -137,7 +139,6 @@ OPENDMARC_STATUS_T opendmarc_policy_fetch_sp(DMARC_POLICY_T *pctx, int *sp);
 u_char **	   opendmarc_policy_fetch_rua(DMARC_POLICY_T *pctx, u_char *list_buf, size_t size_of_buf, int constant);
 u_char **	   opendmarc_policy_fetch_ruf(DMARC_POLICY_T *pctx, u_char *list_buf, size_t size_of_buf, int constant);
 OPENDMARC_STATUS_T opendmarc_policy_fetch_utilized_domain(DMARC_POLICY_T *pctx, u_char *buf, size_t buflen);
-OPENDMARC_STATUS_T opendmarc_policy_fetch_alignment(DMARC_POLICY_T *pctx, int *dkim_alignment, int *spf_alignment);
 OPENDMARC_STATUS_T opendmarc_policy_query_dmarc_xdomain(DMARC_POLICY_T *pctx, u_char *uri);
 
 /*
