@@ -1,5 +1,5 @@
 /*
-**  Copyright (c) 2012-2014, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2012-2015, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -163,7 +163,6 @@ struct dmarcf_config
 	char *			conf_afrfbcc;
 	char *			conf_copyfailsto;
 	char *			conf_reportcmd;
-	char *			conf_tmpdir;
 	char *			conf_authservid;
 	char *			conf_historyfile;
 	char *			conf_pslist;
@@ -1290,10 +1289,6 @@ dmarcf_config_load(struct config *data, struct dmarcf_config *conf,
 		                  &conf->conf_ignoreauthclients,
 		                  sizeof conf->conf_ignoreauthclients);
 
-		(void) config_get(data, "TemporaryDirectory",
-		                  &conf->conf_tmpdir,
-		                  sizeof conf->conf_tmpdir);
-
 		(void) config_get(data, "ReportCommand",
 		                  &conf->conf_reportcmd,
 		                  sizeof conf->conf_reportcmd);
@@ -1465,7 +1460,7 @@ dmarcf_config_reload(void)
 			err = TRUE;
 		}
 
-		if (new->conf_pslist != NULL)
+		if (!err && new->conf_pslist != NULL)
 		{
 			if (opendmarc_tld_read_file(new->conf_pslist, "#",
 			                            NULL, NULL) != 0)
@@ -1475,6 +1470,10 @@ dmarcf_config_reload(void)
 					syslog(LOG_ERR, "%s: read/parse error",
 					       new->conf_pslist);
 				}
+
+				config_free(cfg);
+				dmarcf_config_free(new);
+				err = TRUE;
 			}
 		}
  
@@ -1848,7 +1847,7 @@ mlfi_envfrom(SMFICTX *ctx, char **envfrom)
 		dmarcf_cleanup(ctx);
 
 	if (conf->conf_ignoreauthclients &&
-	    dmarcf_getsymval(ctx, "auth_authen") != NULL)
+	    dmarcf_getsymval(ctx, "{auth_authen}") != NULL)
 		return SMFIS_ACCEPT;
 
 	dfc = (DMARCF_MSGCTX) malloc(sizeof(struct dmarcf_msgctx));
@@ -2075,6 +2074,12 @@ mlfi_eom(SMFICTX *ctx)
 	if (authservid == NULL)
 		authservid = hostname;
 
+	if (conf->conf_dolog)
+	{
+		syslog(LOG_INFO, "implicit authentication service: %s",
+		       authservid);
+	}
+
 	/* ensure there was a From field */
 	from = dmarcf_findheader(dfc, "From", 0);
 
@@ -2434,6 +2439,11 @@ mlfi_eom(SMFICTX *ctx)
 		}
 	}
 
+	/* 
+	**  If we didn't get Authentication-Results for SPF, parse any
+	**  Received-SPF we might have.
+	*/
+
 	if (!wspf
 #if WITH_SPF
 	    && !conf->conf_spfignoreresults
@@ -2566,13 +2576,11 @@ mlfi_eom(SMFICTX *ctx)
 					       AUTHRESULTSHDR);
 				}
 			}
-
-			dmarcf_dstring_printf(dfc->mctx_histbuf, "spf %d\n",
-			                      dfc->mctx_spfresult);
 		}
-		else
 #endif /* WITH_SPF */
-			dmarcf_dstring_printf(dfc->mctx_histbuf, "spf -1\n");
+
+		dmarcf_dstring_printf(dfc->mctx_histbuf, "spf %d\n",
+		                      dfc->mctx_spfresult);
 	}
 
 	ostatus = opendmarc_policy_query_dmarc(cc->cctx_dmarc,
@@ -4535,7 +4543,8 @@ main(int argc, char **argv)
 			}
 		}
 
-		syslog(LOG_INFO, "trusted authentication services: %s",
+		syslog(LOG_INFO,
+		       "additional trusted authentication services: %s",
 		       argstr);
 	}
 
